import React, { Fragment } from 'react'
import { Table, Divider, Row, Col, Alert, Input, Switch } from 'antd';
export default class ItemLoginMethod extends React.Component {

  constructor(props) {
    super(props);
    this.state = {
      data: [],
      unused_data: []
    }
  }

  triggerChange = (changedValue) => {
    // Should provide an event to pass value to Form.
    const onChange = this.props.onChange;
    if (onChange) {
      onChange(changedValue);
    }
  };

  source = [
    {
      order_id: 1,
      name: '邮箱账号',
      type: 'account',
      app_id: '',
      app_key: '',
    },
    {
      order_id: 2,
      name: '谷歌账号',
      type: 'google',
      app_id: '',
      app_key: '',
    },
    {
      order_id: 3,
      name: 'Facebook账号',
      type: 'facebook',
      app_id: '',
      app_key: '',
      use_union_id: false
    },
    {
      order_id: 4,
      name: 'NAVER账号',
      type: 'naver',
      app_id: '',
      app_key: '',
    },
    {
      order_id: 5,
      name: 'Line账号',
      type: 'line',
      app_id: '',
      app_key: '',
    },
    {
      order_id: 6,
      name: 'Twitter账号',
      type: 'twitter',
      app_id: '',
      app_key: '',
    },
    {
      order_id: 7,
      name: 'Apple账号',
      type: 'apple',
      app_id: '',
      app_key: '',
      first_priority_login: false
    },
    {
      order_id: 8,
      name: '游客登录',
      type: 'guest',
      app_id: '',
      app_key: '',
    },
      {
          order_id: 9,
          name: '引继码登录',
          type: 'citation',
          app_id: '',
          app_key: '',
      }
  ]

  columns = [{
    title: '顺序',
    dataIndex: 'order_id',
    key: 'order_id',
    width: 80,
  }, {
    title: '登录方式',
    dataIndex: 'name',
    key: 'name',
    width: 150,
  }, {
    title: '参数',
    dataIndex: 'app_id',
    key: 'app_id',
    width: 250,
    render: (text, record, index) => {
      if (record.type == 'guest' || record.type == 'account' || record.type == 'citation' ) {
        return <span></span>
      }

      let idPlaceholder = 'APP ID'
      let secretPlaceholder = 'APP SECRET'
      switch (record.type) {
        case 'google':
          idPlaceholder = 'Google_SERVER_CLIENT_ID'
          break
        case 'facebook':
          idPlaceholder = 'APP ID'
          secretPlaceholder = 'APP KEY'
          break
        case 'naver':
          idPlaceholder = 'NV_clinet_ID'
          secretPlaceholder = 'NV_clinet_SECRET'
          break
        case 'line':
          idPlaceholder = 'Channel ID'
          secretPlaceholder = 'Channel Secret'
          break
        case 'twitter':
          idPlaceholder = 'Custom key'
          secretPlaceholder = 'Custom Secret'
          break
        case 'apple':
          idPlaceholder = 'APP ID'
      }

      let appSecretDom = ''
      let unionIDDom = ''
      let priorityLoginDom = ''
      if (record.type == 'facebook' || record.type == 'naver' || record.type == 'line' || record.type == 'twitter') {
        appSecretDom = (
          <div style={{ marginTop: "15px" }}>
            <span>
              {secretPlaceholder}
            </span>
            <Input placeholder={secretPlaceholder} value={record.app_key}
              onChange={(e) => {
                this.state.data[index].app_key = e.target.value
                // this.setState({ data: this.state.data })
                this.triggerChange(this.state.data)
              }}
            />
          </div>
        )
      }

      if (record.type == 'facebook') {
        let defaultChecked = record.use_union_id == 1 ? true : false
        unionIDDom = (
          <div style={{ marginTop: "15px" }}>
            <div>
              UnionID开关
            </div>
            <Switch checkedChildren="开启" unCheckedChildren="关闭" checked={defaultChecked} onChange={(checked) => {
              this.state.data[index].use_union_id = checked === true ? 1 : 0
              // this.setState({ data: this.state.data })
              this.triggerChange(this.state.data)
            }} />
          </div>
        )
      }

      if (record.type == 'apple') {
        let defaultChecked = record.first_priority_login == 1 ? true : false
        priorityLoginDom = (
          <div style={{ marginTop: "15px"}}>
            <div>
              首次启动自动登陆开关
            </div>
            <Switch checkedChildren="开启" unCheckedChildren="关闭" checked={defaultChecked} onChange={(checked) => {
              this.state.data[index].first_priority_login = checked === true ? 1: 0
              this.triggerChange(this.state.data)
            }}/>
          </div>
        )
      }

      return (
        <div>
          <div>
            <span>
              {idPlaceholder}
            </span>
            <Input placeholder={idPlaceholder} value={record.app_id}
              onChange={(e) => {
                this.state.data[index].app_id = e.target.value
                // this.setState({ data: this.state.data })
                this.triggerChange(this.state.data)
              }}
            />
            <br />
          </div>
          {appSecretDom}
          {unionIDDom}
          {priorityLoginDom}
        </div>
      )
    }
  }, {
    title: '操作',
    dataIndex: 'action',
    key: 'action',
    width: 180,
    render: (text, record, index) => {
      if(record.type !== 'guest'){
        return <span >
        <a disabled={index == 0} onClick={() => {
          let item = this.state.data.splice(index, 1)[0]
          this.state.data.splice(index - 1, 0, item)
          this.triggerChange(this.state.data)
        }}>上移</a>
        <Divider type="vertical" />
        <a disabled={index == this.state.data.length - 1} onClick={() => {
          let item = this.state.data.splice(index, 1)[0]
          this.state.data.splice(index + 1, 0, item)
          this.triggerChange(this.state.data)
        }}>下移</a>
        <Divider type="vertical" />
        <a onClick={() => {
          let item = this.state.data.splice(index, 1)
          this.triggerChange(this.state.data)
        }}>删除</a>
      </span>
      }else {
        return <span >
        <a onClick={() => {
          let item = this.state.data.splice(index, 1)
          this.triggerChange(this.state.data)
        }}>删除</a>
      </span>
      }

      }
  }];

  unused_columns = [{
    title: '登录方式',
    dataIndex: 'name',
    key: 'name',
  }, {
    title: '操作',
    dataIndex: 'action',
    key: 'action',
    render: (text, record, index) => (
      <a onClick={() => {
        this.addLoginType(record);
        this.triggerChange(this.state.data)
      }}>添加</a>
    )
  }];

  addLoginType = (record) => {
    let guestIndex = 0;
    let hasGuest = false;
    if(record.type !== 'guest'){
      this.state.data.map((item,index)=>{
        if(item.type === 'guest'){
          guestIndex = index;
          hasGuest = true;
        }
      });
      if(hasGuest){
        this.state.data.splice(guestIndex,0,record)
      }else {
        this.state.data.push(record)
      }
    }else {
      this.state.data.push(record)
    }
};


  componentWillReceiveProps(props) {
    const datasource = props.value || [];
    let data = []
    let unused_data = []
    if (datasource.length == 0) {
      if (this.state.unused_data.length == 0) {
        data = JSON.parse(JSON.stringify(this.source))
      }else{
        unused_data = JSON.parse(JSON.stringify(this.source))
      }
    } else {
      data = datasource
      this.source.forEach(row => {
        let item = datasource.find(i => {
          return row.type == i.type
        })
        if (!item) {
          unused_data.push(row)
        }
      })
    }
    let order_id = 1;
    for(let item of data){
      item.order_id = order_id++
    }

    this.setState({
      data: data,
      unused_data: unused_data
    })
  }

  render() {
    return (
      <Fragment>
        <Alert message="登录方式按顺序从小到大排序（UI从右到左）" type="warning" showIcon />
        <br />
        <Row gutter={24}>
          <Col span={18} >
            <Table rowKey="type" dataSource={this.state.data} columns={this.columns} title={() => '已选登录方式'} bordered pagination={false} />
          </Col>
          <Col span={6} >
            <Table rowKey="type" dataSource={this.state.unused_data} columns={this.unused_columns} bordered title={() => '未选登录方式'} pagination={false} />
          </Col>
        </Row>
      </Fragment>
    )
  }
}
